//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id$
//
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#ifndef ComplexGeometry_h
#define ComplexGeometry_h 1

#include "globals.hh"
#include "G4VUserDetectorConstruction.hh"

class G4Box;
class G4Tubs;
class G4Trd;
class G4LogicalVolume;
class G4VPhysicalVolume;
class G4Material;

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

class ComplexGeometry : public G4VUserDetectorConstruction
{
public:
  
  ComplexGeometry();
  ~ComplexGeometry();

public:
  
  G4VPhysicalVolume* Construct();

  G4VPhysicalVolume* GetPhysicalWorld() {return physiWorld;}
     
private:

  G4Box*             solidWorld;    // pointer to the solid envelope 
  G4LogicalVolume*   logicWorld;    // pointer to the logical envelope
  G4VPhysicalVolume* physiWorld;    // pointer to the physical envelope
     
  G4Box*             solidTarget;   // pointer to the solid Target
  G4LogicalVolume*   logicTarget;   // pointer to the logical Target
  G4VPhysicalVolume* physiTarget;   // pointer to the physical Target
               
  G4Box*             solidBoxDetector;  // pointer to the solid Detector
  G4LogicalVolume*   logicBoxDetector;  // pointer to the logical Detector
  G4VPhysicalVolume* physiBoxDetector;  // pointer to the physical Detector

  G4Tubs*             solidTubsDetector;  // pointer to the solid Detector
  G4LogicalVolume*   logicTubsDetector;  // pointer to the logical Detector
  G4VPhysicalVolume* physiTubsDetector;  // pointer to the physical Detector

  G4Trd*             solidTrapezoidDetector;  // pointer to the solid Detector
  G4LogicalVolume*   logicTrapezoidDetector;  // pointer to the logical Detector
  G4VPhysicalVolume* physiTrapezoidDetector;  // pointer to the physical Detector
     
  G4Material*         TargetMater;   // pointer to the target material
  G4Material*         DetectorMater; // pointer to the detector material

};

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#endif
