//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#ifndef aHit_h
#define aHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"

//! Informations to be kept at each step if a positive energy is deposited in a sensitive detector
/*!
    Only position, energy deposited and particle name is kept
 */
class aHit : public G4VHit
{
private:
    G4double edep;
    G4String particleName;
    G4ThreeVector pos;
    
public:
    aHit();
    aHit(const aHit &right);
    virtual ~aHit();

    void Draw();
    void Print();
    
    void SetParticle  (G4String name)
    {
        particleName = name;
    }
    void SetEdep(G4double de)
    {
        edep = de;
    }
    void SetPos(G4ThreeVector xyz)
    {
        pos = xyz;
    }

    G4String GetDetID()
    {
        return particleName;
    }
    
    G4double GetEdep()
    {
        return edep;
    }
    G4ThreeVector &GetPos()
    {
        return pos;
    }
    
    
public:
    const aHit& operator=(const aHit &right);
    G4int operator==(const aHit &right) const;
    
    inline void *operator new(size_t);
    inline void operator delete(void *aHit);
};

// this is to have an efficient memory allocation system
typedef G4THitsCollection<aHit> aHitsCollection;

extern G4Allocator<aHit> aHitAllocator;

inline void* aHit::operator new(size_t)
{
    void *aHit;
    aHit = (void *) aHitAllocator.MallocSingle();
    return aHit;
}
inline void aHit::operator delete(void *hit)
{
    aHitAllocator.FreeSingle((aHit*) hit);
}

#endif

