#include "SteppingAction.hh"

#include "G4UnitsTable.hh"
#include "G4Track.hh"
#include "G4RunManager.hh"
#include "G4Event.hh"


#include <algorithm>


//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

SteppingAction::SteppingAction()
{ 
  volumesName.clear();
  trackID = -1; // dummy value
  eventID = -1; // dummy value
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void SteppingAction::UserSteppingAction(const G4Step* aStep)
{ 
  // protection against out of world case
  if(!aStep->GetTrack()->GetTouchable()->GetVolume()) return;


  // check if it is the same particle and the same event
  // if it is not -> clear vector of volumes of the previous particle and assign new values for the variables
  const G4int id_track = aStep->GetTrack()->GetTrackID();
  const G4int id_event = G4RunManager::GetRunManager()->GetCurrentEvent()->GetEventID();
  if( trackID != id_track || id_event != eventID ){
    trackID = id_track;
    eventID = id_event;
    volumesName.clear();
  }
  
  const G4String currentVolumeName = aStep->GetTrack()->GetTouchable()->GetVolume()->GetName();
  // check if it is the first time inside this volume
  if( std::find(volumesName.begin(), volumesName.end(), currentVolumeName) != volumesName.end()) return;

  volumesName.push_back(currentVolumeName);
  
  const G4double stepLength = aStep->GetStepLength();
  const G4String volumeName = aStep->GetTrack()->GetTouchable()->GetVolume()->GetName();

  G4cout << G4endl << "&&&&&&&&& INFO &&&&&&&&&" << G4endl;
  G4cout << "FIRST STEP IN VOLUME \"" << volumeName << "\" WITH A STEP LENGTH OF " << G4BestUnit(stepLength, "Length") << G4endl << G4endl;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

