//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "aHit.hh"
#include "G4VVisManager.hh"
#include "G4Circle.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4UnitsTable.hh"

G4Allocator<aHit> aHitAllocator;

aHit::aHit()
{;}

aHit::~aHit()
{;}

aHit::aHit(const aHit &from) : G4VHit()
{
  if ( this == &from )
    return;

  particleName = from.particleName;
  edep = from.edep;
  pos  = from.pos;
}

const aHit& aHit::operator=(const aHit &from)
{
  if ( this == &from )
    return (*this);
	
  particleName = from.particleName;
  edep = from.edep;
  pos  = from.pos;
    
  return (*this);
}

G4int aHit::operator==(const aHit &from) const
{
  return (this==&from) ? 1 : 0;
}

void aHit::Draw()
{
  G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
  if(pVVisManager)
    {
      G4Circle circle(pos);
      circle.SetScreenSize(0.04); circle.SetFillStyle(G4Circle::filled);
		
      G4Colour colour(1.,0.,0.);
      G4VisAttributes attribs(G4Colour(1.,0.,0.)); circle.SetVisAttributes(attribs);
      pVVisManager->Draw(circle);
    }
}

void aHit::Print()
{
  G4cout << "A " << particleName << " has deposited " << G4BestUnit(edep, "Energy") << " in the position: " << pos << G4endl; 
}



