//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "aTrackerSD.hh"
#include "aHit.hh"

#include "G4Step.hh"
#include "G4HCofThisEvent.hh"
#include "G4TouchableHistory.hh"
#include "G4VProcess.hh"
#include "G4ios.hh"

#include "G4RunManager.hh"
#include "G4Event.hh"
#include "G4Track.hh"


aTrackerSD::aTrackerSD(G4String name): G4VSensitiveDetector(name)
{
  G4String HCname = "singleCollection"; collectionName.insert(HCname); 
	
}

aTrackerSD::~aTrackerSD()
{}


void aTrackerSD::Initialize(G4HCofThisEvent* HCE)
{
  static int HCID = -1;
  trackerCollection = new aHitsCollection(SensitiveDetectorName, collectionName[0]); 
	
  if ( HCID < 0 ) HCID = GetCollectionID(0);

  HCE->AddHitsCollection(HCID,trackerCollection);
}

G4bool aTrackerSD::ProcessHits(G4Step* aStep, G4TouchableHistory *)
{
  // nothing to be stored if no energy
  G4double edep = aStep->GetTotalEnergyDeposit();  
  if ( edep <= 0. ) return false;
  
  // a new hit is created
  aHit *newHit = new aHit();
	
  // set hit properties
  newHit->SetEdep( edep );
  newHit->SetPos( aStep->GetPostStepPoint()->GetPosition() );
  newHit->SetParticle( aStep->GetTrack()->GetDefinition()->GetParticleName() );
			
  // add this hit to the collection
  trackerCollection->insert( newHit );

  return true;
}

void aTrackerSD::EndOfEvent(G4HCofThisEvent*)
{
  const G4int NbHits = trackerCollection->entries();
  if(NbHits == 0) return;

  const G4int event_nb = G4RunManager::GetRunManager()->GetCurrentEvent()->GetEventID();
  
  G4cout << "\n--------> Hits Collection: in the event number " << event_nb 
	 << " there were " << NbHits 
	 << " hits in the " << SensitiveDetectorName << ": " << G4endl;
  
  for (G4int i = 0; i < NbHits; i++) 
    (*trackerCollection)[i]->Print();

  G4cout << G4endl << G4endl;
}

